==> dl.php?src=linea21_2_0_0.zip: linea21/newsletter/sup.php <==
<?php
/**
 * Newsletter module
 * 
 * Delete given newsletter from back-office. Available if the newsletter has not been send already 
 * 
 * @package linea21\modules\newsletter
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id;


if(isset($_POST['valider'])) {
  $newsletter_object = new newsletter;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$newsletter_object->DeleteNewsletter($id, $sql_object);
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$result=$sql_object->DBSelect(SQL_getNewsletterTitle($id));

// Do record exists?
if(!isset($result[0]['newsletter_title'])) redirect_to('@module_default');

$newsletter_title=FormatText($result[0]['newsletter_title']);
$newsletter_status=$result[0]['newsletter_statut'];

//////////// Check Droits utilisateur + statut newsletter courante ////////////
if (!$l21auth->isSuperAdmin() || $newsletter_status=='P') ReloadIndex('admin');
////////////
?>

<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','newsletter'); ?></a></li>
	<li><span><?php echo formatNavTitle(_t('newsletter','sup')." : ". $newsletter_title); ?></span></li>
</ul>
</div>
<!--end barre haute -->

<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<?php echo "<h2>". formatTitleh2($newsletter_title)."</h2>"; ?>
<form id="supnewsletter" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<p class="info"><i class="icon-trash"></i> <?php echo _t('divers','sup_confirm'); ?></p>

	<div>
		<input name="id" type="hidden" value="<?php echo $id; ?>" />
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<?php echo cancel_button('javascript:history.go(-1);'); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid'); ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->

==> dl.php?src=linea21_2_3_0.zip: linea21/newsletter/sup.php <==
<?php
/**
 * Newsletter module
 * 
 * Delete given newsletter from back-office. Available if the newsletter has not been send already 
 * 
 * @package linea21\modules\newsletter
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id;


if(isset($_POST['valider'])) {
  $newsletter_object = new newsletter;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$newsletter_object->DeleteNewsletter($id, $sql_object);
  if($result) header("Location: ".safe_redirect($link_confirm));
  else  system_error();
}

$result=$sql_object->DBSelect(SQL_getNewsletterTitle($id));

// Do record exists?
if(!isset($result[0]['newsletter_title'])) redirect_to('@module_default');

$newsletter_title=FormatText($result[0]['newsletter_title']);
$newsletter_status=$result[0]['newsletter_statut'];

//////////// Check Droits utilisateur + statut newsletter courante ////////////
if (!$l21auth->isSuperAdmin() || $newsletter_status=='P') ReloadIndex('admin');
////////////
?>

<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','newsletter'); ?></a></li>
	<li><span><?php echo formatNavTitle(_t('newsletter','sup')." : ". $newsletter_title); ?></span></li>
</ul>
</div>
<!--end barre haute -->

<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<?php echo "<h2>". formatTitleh2($newsletter_title)."</h2>"; ?>
<form id="supnewsletter" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<p class="info"><i class="icon-trash"></i> <?php echo _t('divers','sup_confirm'); ?></p>

	<div>
		<input name="id" type="hidden" value="<?php echo $id; ?>" />
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<?php echo cancel_button('javascript:history.go(-1);'); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid'); ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
